@@ -1,3 +1,17 @@
+# Copyright 2021 The google-cloud-mlflow Authors.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 """MLflow deployment plugin to deploy MLflow models to Google Cloud Vertex AI."""
 
 __all__ = [
@@ -8,12 +22,14 @@ __all__ = [
 
 import json
 import logging
-from typing import Any, Dict, List, Optional, TYPE_CHECKING, Union
+from typing import Any, Dict, List, Optional, Union
 
 from . import _mlflow_model_gcp_deployment_utils as vertex_utils
 from google.protobuf import json_format
 import mlflow
 from mlflow import deployments
+import numpy
+import pandas
 
 # TODO(b/195784726) Remove this workaround once google-cloud-aiplatform conforms
 # to the third_party python rules
@@ -22,11 +38,6 @@ try:
 except ImportError:
     from google.cloud.aiplatform import aiplatform  # pylint:disable=g-import-not-at-top
 
-if TYPE_CHECKING:
-    # These imports are only used to specify the parameter types and return types
-    # for the predict can explain methods.
-    import pandas  # pylint:disable=g-import-not-at-top
-    import numpy  # pylint:disable=g-import-not-at-top
 
 _logger = logging.getLogger(__name__)
 
@@ -49,6 +60,18 @@ def _resource_to_mlflow_dict(
     return resource_dict
 
 
+def _data_to_list_of_instances(
+    data: Union[list, numpy.ndarray, pandas.DataFrame]
+) -> List:
+    if isinstance(data, pandas.DataFrame):
+        return data.values.tolist()
+    if isinstance(data, numpy.ndarray):
+        return data.tolist()
+    if isinstance(data, list):
+        return data
+    raise TypeError(f"Unsupported data type {type(data)}")
+
+
 class GoogleCloudVertexAiDeploymentClient(deployments.BaseDeploymentClient):
     """The Google Cloud Vertex AI implementation of the BaseDeploymentClient."""
 
@@ -91,19 +114,15 @@ class GoogleCloudVertexAiDeploymentClient(deployments.BaseDeploymentClient):
 
                     # Model container image building config
                     destination_image_uri=None,
-                    timeout=None,
-
-                    # Model deployment config
-                    sync="true",
 
                     # Endpoint config
-                    description=None,
+                    endpoint_description=None,
+                    endpoint_deploy_timeout=None,
 
                     # Vertex AI config
                     project=None,
                     location=None,
-                    experiment=None,
-                    experiment_description=None,
+                    encryption_spec_key_name=None,
                     staging_bucket=None,
                 )
             )
@@ -122,35 +141,40 @@ class GoogleCloudVertexAiDeploymentClient(deployments.BaseDeploymentClient):
             A dict corresponding to the created deployment, which must contain the 'name' key.
         """
         config = config or {}
-        existing_endpoints = aiplatform.Endpoint.list(filter=f'display_name="{name}"')
+
+        project = config.get("project")
+        location = config.get("location")
+        encryption_spec_key_name = config.get("encryption_spec_key_name")
+        staging_bucket = config.get("staging_bucket")
+
+        existing_endpoints = aiplatform.Endpoint.list(
+            filter=f'display_name="{name}"',
+            project=project,
+            location=location,
+        )
         if existing_endpoints:
             raise mlflow.exceptions.MlflowException(
                 f"Found existing deployment with name {name}: " +
                 ",".join(list(endpoint.resource_name for endpoint in existing_endpoints)))
 
-        aiplatform.init(
-            project=config.get("project"),
-            location=config.get("location"),
-            experiment=config.get("experiment"),
-            experiment_description=config.get("experiment_description"),
-            staging_bucket=config.get("staging_bucket"),
-            encryption_spec_key_name=config.get("encryption_spec_key_name"),
+        model_name = vertex_utils.upload_mlflow_model_to_vertex_ai_models(
+            model_uri=model_uri,
+            display_name=name,
+            destination_image_uri=config.get("destination_image_uri"),
+            project=project,
+            location=location,
+            encryption_spec_key_name=encryption_spec_key_name,
+            staging_bucket=staging_bucket,
         )
-        model_name = config.get("model_resource_name")
-        if not model_name:
-            model_name = vertex_utils.upload_mlflow_model_to_vertex_ai_models(
-                model_uri=model_uri,
-                display_name=name,
-                destination_image_uri=config.get("destination_image_uri"),
-                timeout=int(config.get("timeout", 1800)),
-            )
         endpoint = aiplatform.Endpoint.create(
             display_name=name,
-            description=config.get("description"),
-            encryption_spec_key_name=config.get("encryption_spec_key_name"),
+            description=config.get("endpoint_description"),
             labels={
-                "google_cloud_mlflow_plugin_version": "0.0.1",
+                "google_cloud_mlflow_plugin_version": "0-0-1",
             },
+            project=project,
+            location=location,
+            encryption_spec_key_name=encryption_spec_key_name,
         )
         endpoint.deploy(
             model=aiplatform.Model(model_name=model_name),
@@ -170,6 +194,7 @@ class GoogleCloudVertexAiDeploymentClient(deployments.BaseDeploymentClient):
             explanation_metadata=(json.loads(config.get("explanation_metadata")) if "explanation_metadata" in config else None),
             explanation_parameters=(json.loads(config.get("explanation_parameters")) if "explanation_parameters" in config else None),
             sync=json.loads(config.get("sync", "true")),
+            deploy_request_timeout=int(config.get("endpoint_deploy_timeout", 1800)),
         )
 
         deployment_dict = _resource_to_mlflow_dict(endpoint)
@@ -279,8 +304,10 @@ class GoogleCloudVertexAiDeploymentClient(deployments.BaseDeploymentClient):
         )
 
     def predict(
-        self, deployment_name: str, df: "pandas.DataFrame"
-    ) -> Union["pandas.DataFrame", "pandas.Series", "numpy.ndarray", Dict[str, Any]]:
+        self,
+        deployment_name: str,
+        df: Union[List, numpy.ndarray, pandas.DataFrame],
+    ) -> Union[pandas.DataFrame, pandas.Series, numpy.ndarray, Dict[str, Any]]:
         """Computes model predictions.
 
         Compute predictions on the pandas DataFrame ``df`` using the specified
@@ -311,11 +338,15 @@ class GoogleCloudVertexAiDeploymentClient(deployments.BaseDeploymentClient):
         """
         endpoint = self._get_deployment(deployment_name=deployment_name)
         predictions = endpoint.predict(
-            instances=df.to_dict("records")
+            instances=_data_to_list_of_instances(df),
         )
         return predictions
 
-    def explain(self, deployment_name: str, df: "pandas.DataFrame"):
+    def explain(
+        self,
+        deployment_name: str,
+        df: Union[List, numpy.ndarray, pandas.DataFrame],
+    ) -> Union[pandas.DataFrame, pandas.Series, numpy.ndarray, Dict[str, Any]]:
         """Generates explanations of model predictions.
 
         Generate explanations of model predictions on the specified input pandas Dataframe
@@ -346,7 +377,7 @@ class GoogleCloudVertexAiDeploymentClient(deployments.BaseDeploymentClient):
         """
         endpoint = self._get_deployment(deployment_name=deployment_name)
         predictions = endpoint.explain(
-            instances=df.to_dict("records")
+            instances=_data_to_list_of_instances(df),
         )
         return predictions
 
@@ -401,7 +432,6 @@ def target_help():
 
                     # Model container image building config
                     destination_image_uri=None,
-                    timeout=None,
 
                     # Model deployment config
                     sync="true",
